@@ -111,6 +111,14 @@ def plot_event(event_name, pickle_dir, settings_filename,
 
     Also plots MISO estimates and Psi values.
     """
+    if not os.path.isfile(settings_filename):
+        print "Error: settings filename %s not found." %(settings_filename)
+        sys.exit(1)
+
+    if not os.path.isdir(pickle_dir):
+        print "Error: event pickle directory %s not found." %(pickle_dir)
+        sys.exit(1)
+        
     # Retrieve the full pickle filename
     genes_filename = os.path.join(pickle_dir,
                                   "genes_to_filenames.shelve")
@@ -143,8 +151,10 @@ def plot_insert_len(insert_len_filename,
     """
     Plot insert length distribution.
     """
+    if not os.path.isfile(settings_filename):
+        print "Error: settings filename %s not found." %(settings_filename)
+        sys.exit(1)
     plot_name = os.path.basename(insert_len_filename)
-    
     sashimi_obj = Sashimi(plot_name, output_dir,
                           settings_filename=settings_filename)
     settings = sashimi_obj.settings
@@ -191,6 +201,9 @@ def plot_posterior(miso_filename, settings_filename, output_dir,
     """
     Plot posterior distribution.
     """
+    if not os.path.isfile(settings_filename):
+        print "Error: settings filename %s not found." %(settings_filename)
+        sys.exit(1)
 #    samples, log_scores, params, gene = load_samples(miso_filename)
     samples, h, log_scores, sampled_map,\
              sampled_map_log_score, counts_info = load_samples(miso_filename)
