@@ -43,6 +43,9 @@ static PyObject* pysplicing_miso(PyObject *self, PyObject *args) {
   int gene, readLength, noIterations=5000, maxIterations=100000, 
     noBurnIn=500, noLag=10;
   int overhang=1;
+  int no_chains=6;
+  splicing_miso_start_t start=SPLICING_MISO_START_AUTO;
+  splicing_miso_stop_t stop=SPLICING_MISO_STOP_CONVERGENT_MEAN;
   splicing_gff_t *mygff;
   splicing_strvector_t myreadcigar;
   splicing_vector_int_t myreadpos;
@@ -55,9 +58,12 @@ static PyObject* pysplicing_miso(PyObject *self, PyObject *args) {
   splicing_miso_rundata_t rundata;
   PyObject *r1, *r2, *r3, *r4, *r5, *r6;
   
-  if (!PyArg_ParseTuple(args, "OiOOi|iiiOi", &gff, &gene, &readpos, &readcigar,
+  if (!PyArg_ParseTuple(args, "OiOOi|iiiOiiii", 
+			&gff, &gene, &readpos, &readcigar,
 			&readLength, &noIterations, &noBurnIn, &noLag, 
-			&hyperp, &overhang)) { return NULL; }
+			&hyperp, &overhang, &no_chains, &start, &stop)) { 
+    return NULL; 
+  }
   
   mygff=PyCObject_AsVoidPtr(gff);
 
@@ -88,11 +94,10 @@ static PyObject* pysplicing_miso(PyObject *self, PyObject *args) {
   
   SPLICING_PYCHECK(splicing_miso(mygff, gene, &myreadpos, 
 				 (const char**) myreadcigar.table, 
-				 readLength, overhang, /*noChains=*/ 1L,
+				 readLength, overhang, no_chains,
 				 noIterations, maxIterations, 
 				 noBurnIn, noLag,
-				 &myhyperp, SPLICING_MISO_START_AUTO, 
-				 SPLICING_MISO_STOP_FIXEDNO, 0,
+				 &myhyperp, start, stop, 0,
 				 &samples, &logLik, 
 				 /*match_matrix=*/ 0, &class_templates,
 				 &class_counts, &assignment, &rundata));
@@ -147,6 +152,9 @@ static PyObject* pysplicing_miso_paired(PyObject *self, PyObject*args) {
   int gene, readLength, noIterations=5000, maxIterations=100000, 
     noBurnIn=500, noLag=10;
   int overhang=1;
+  int no_chains=6;
+  splicing_miso_start_t start=SPLICING_MISO_START_AUTO;
+  splicing_miso_stop_t stop=SPLICING_MISO_STOP_CONVERGENT_MEAN;
   double normalMean, normalVar, numDevs;
   splicing_gff_t *mygff;
   splicing_strvector_t myreadcigar;
@@ -160,10 +168,12 @@ static PyObject* pysplicing_miso_paired(PyObject *self, PyObject*args) {
   splicing_miso_rundata_t rundata;
   PyObject *r1, *r2, *r3, *r4, *r5, *r6;
   
-  if (!PyArg_ParseTuple(args, "OiOOiddd|iiiOi", &gff, &gene, &readpos, 
+  if (!PyArg_ParseTuple(args, "OiOOiddd|iiiOiiii", &gff, &gene, &readpos, 
 			&readcigar, &readLength, &normalMean, &normalVar,
 			&numDevs, &noIterations, &noBurnIn, &noLag,
-			&hyperp, &overhang)) { return NULL; }
+			&hyperp, &overhang, &no_chains, &start, &stop)) { 
+    return NULL; 
+  }
 
   mygff=PyCObject_AsVoidPtr(gff);
   
@@ -196,9 +206,9 @@ static PyObject* pysplicing_miso_paired(PyObject *self, PyObject*args) {
   
   splicing_miso_paired(mygff, gene, &myreadpos,
 		       (const char**) myreadcigar.table, readLength,
-		       overhang, /*noChains=*/ 1, noIterations, 
+		       overhang, no_chains, noIterations, 
 		       maxIterations, noBurnIn, noLag, &myhyperp, 
-		       /*start=*/ 0, /*stop=*/ 0, /*start_psi=*/ 0,
+		       start, stop, /*start_psi=*/ 0,
 		       /*insertProb=*/ 0, /*insertStart=*/ 0,
 		       normalMean, normalVar, numDevs, &samples, &logLik,
 		       /*match_matrix=*/ 0, /*class_templates=*/ 0, 
@@ -414,8 +424,10 @@ static PyObject* pysplicing_solve_gene(PyObject *self, PyObject *args) {
   SPLICING_PYCHECK(splicing_solve_gene(mygff, gene, readLength, overhang,
 				       &myposition, 
 				       (const char **) myreadcigar.table,
-				       &match_matrix, &assignment_matrix,
-				       &expression));
+				       &match_matrix, /*nomatch=*/ 0, 
+				       &assignment_matrix,
+				       &expression, /*residuals=*/ 0, 
+				       /*scale=*/ 0));
   
   r1=pysplicing_from_matrix(&match_matrix);
   r2=pysplicing_from_matrix(&assignment_matrix);
